# George Washington Neural Network
This repository contains a neural network library built from scratch for use in Neural Network courses at
The George Washington University. It is a basic implementation that provides a number of layers, activation
functions, and loss functions for students to explore how networks work at a low level. 